%define major		56
%define libname 	%mklibname icu %{major}
%define develname 	%mklibname icu -d

%define dataname	%{name}%{major}-data

%define tarballver	%(echo %version|sed -e 's|\\.|_|g')

Summary:	International Components for Unicode
Name:		icu
Version:	56.1
Release:	%mkrel 1
License:	MIT
Group:		System/Libraries
URL:		http://www.icu-project.org/index.html
Source0:	http://download.icu-project.org/files/icu4c/%{version}/%{name}4c-%{tarballver}-src.tar.xz
Source1:	http://download.icu-project.org/files/icu4c/%{version}/%{name}4c-%{tarballver}-docs.zip
Patch0:		icu-50.1-disable-renaming.patch
Patch14:	icu-52.1-CVE-2015-4760.patch
BuildRequires:	doxygen
Requires:	%{libname} = %{version}

%description
The International Components for Unicode (ICU) libraries provide robust and
full-featured Unicode services on a wide variety of platforms. ICU supports
the most current version of the Unicode standard, and they provide support
for supplementary Unicode characters (needed for GB 18030 repertoire support).

As computing environments become more heterogeneous, software portability
becomes more important. ICU lets you produce the same results across all the
various platforms you support, without sacrificing performance. It offers
great flexibility to extend and customize the supplied services, which
include:

  * Text: Unicode text handling, full character properties and character set
    conversions (500+ codepages)
  * Analysis: Unicode regular expressions; full Unicode sets; character, word
    and line boundaries
  * Comparison: Language sensitive collation and searching
  * Transformations: normalization, upper/lowercase, script transliterations
    (50+ pairs)
  * Locales: Comprehensive locale data (230+) and resource bundle architecture
  * Complex Text Layout: Arabic, Hebrew, Indic and Thai
  * Time: Multi-calendar and time zone
  * Formatting and Parsing: dates, times, numbers, currencies, messages and
    rule based

%package -n %{dataname}
Summary:	Shared data for the International Components for Unicode
Group:		System/Libraries
BuildArch:	noarch
Conflicts:	icu-devel < 50.1

%description -n %{dataname}
Shared data for the International Components for Unicode.

%package doc
Summary:	Documentation for the International Components for Unicode
Group:		Documentation
Requires:	%{name}
BuildArch:	noarch

%description doc
Documentation for the International Components for Unicode.

%package -n %{libname}
Summary:	Libraries for the International Components for Unicode
Group:		System/Libraries
Requires:	%{dataname} = %{version}-%{release}

%description -n %{libname}
Libraries for the International Components for Unicode.

%package -n %{develname}
Summary:	Development files for the International Components for Unicode
Group:		Development/Libraries
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}%{major}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Obsoletes:	%mklibname -d icu 36
Obsoletes:	%mklibname -d icu 34

%description -n	%{develname}
Development files and headers for the International Components for Unicode.

%prep
%setup -q -n %{name}
%patch0 -p1 -b .renaming
%patch14 -p1 -b .CVE-2015-4760

mkdir -p docs
pushd docs
	unzip -q %{SOURCE1}
popd

%build
pushd source
%configure2_5x \
	--with-library-bits=64else32 \
	--with-data-packaging=archive \
	--disable-renaming \
	--disable-samples
%make
%make doc
popd

%install
rm -rf %buildroot
%makeinstall_std -C source
%multiarch_binaries %{buildroot}%{_bindir}/icu-config

%files
%{_bindir}/*
%exclude %{_bindir}/icu-config
%exclude %{multiarch_bindir}
%{_sbindir}/*

%files -n %{dataname}
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/%{version}
%{_datadir}/%{name}/%{version}/icudt%{major}l.dat

%files doc
%doc readme.html docs/*
%{_mandir}/man1/*
%{_mandir}/man8/*

%files -n %{libname}
%{_libdir}/*.so.%{major}*

%files -n %{develname}
%{_bindir}/icu-config
%{multiarch_bindir}/icu-config
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%dir %{_includedir}/layout
%dir %{_includedir}/unicode
%{_includedir}/layout/*
%{_includedir}/unicode/*
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/%{version}
%{_libdir}/%{name}/%{version}/Makefile.inc
%{_libdir}/%{name}/%{version}/pkgdata.inc
%{_libdir}/%{name}/Makefile.inc
%{_libdir}/%{name}/current
%{_libdir}/%{name}/pkgdata.inc
%{_datadir}/%{name}/%{version}/config
%{_datadir}/%{name}/%{version}/install-sh
%{_datadir}/%{name}/%{version}/license.html
%{_datadir}/%{name}/%{version}/mkinstalldirs


%changelog
* Mon Apr 25 2016 bb <bb> 56.1-1pclos2016
- update

